/*	Copyright (C) 2005, 2006 by Andy Grebe a.k.a. tecknophreak(tecknophreak@gmail.com)
 *
 *	This file is part of TouchMe Games.
 *
 *	TouchMe Games is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	TouchMe Games is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with TouchMe Games; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef DART_COUNTUP_H
#define DART_COUNTUP_H

#include <iostream>
#include <string>
#include <map>
#include <gameptr.h>
#include <termios.h>
#include <unistd.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <fcntl.h>
#include <dartlib.h>

#define dart01Path "/usr/local/share/touchmegames/dart01/"

class DART_COUNTUP : public GAME_PTR {
private:
	int round;
	GtkWidget *fixed;
	GtkWidget *roundLabel;
	GtkWidget *ppdWindow;
	GtkWidget *ppdVbox;
	GtkWidget *ppdPlayerLabel;
	GtkWidget *ppdLabel;
	
	std::string gameName;
	GtkWidget *tophbox;
	gint timer;
	int totalScore;
	bool doubleBullOn;
	
	int numberOfPlayers;
	int currentPlayer;
	int currentScore;
	int currentDart;
	int gameState;
	enum GAME_STATES {
		PLAYING,
		GAME_OVER1,
		GAME_OVER2
	};
	
	// Serial Port settings
	DartLib dartBoard;
	
	// Statistics
	int darts[8];
	int finalScore[8];
	int rounds[8];
	int doubles[8];
	int triples[8];
	int bulls[8];
	int winner;
	int beginningScore; // for when the player busts
	
	// interface
	// opening screen
	GtkWidget *table;
	GtkWidget *numPlayersEntry, *doubleBullLabel;
	
	// playing screen
	GtkWidget *lhvbox, *rhvbox, *midvbox;
	
	GtkWidget *createOpenScreen();
	void createPPDWindow();
	void createGameOver1();
	
	void openSerial();
	
	// game screen
	void initScreen();
	
	GtkWidget *playerLabels[8];
	GtkWidget *playerScoreLabels[8];
	GtkWidget *currentTotalLabel;
	GtkWidget *currentScoreLabel;
	GtkWidget *dartImages[3];
	GtkWidget *dartLabels[3];
	GtkWidget *playerLabel;
	// events
	static void exitGame(GtkWidget *widget, GdkEvent *event, gpointer ptr);
	static void changeNumPlayers(GtkWidget *widget, gpointer ptr);
	static void changeGame(GtkWidget *widget, gpointer ptr);
	static void onOffToggle(GtkWidget *widget, gpointer ptr);
	static gboolean timeout(gpointer ptr);
	
	static void startGame(GtkWidget *widget, gpointer ptr);
	
	void runGameOver();
	
	
	SCORE_STRUCT scores[10];
	GdkColor bgcolor;
public:
	DART_COUNTUP();
	virtual ~DART_COUNTUP();
	
	std::string name() const;
	std::string imageName() const;
	GdkColor *backgroundColor();
	// initializes the game's variables and returns the
	// top level h/vbox
	GtkWidget *init();
	int gameType() const;
	unsigned int score() const { return 0; };
};

#endif // DART_COUNTUP_H
