

/*	Copyright (C) 2005, 2006 by Andy Grebe a.k.a. tecknophreak(tecknophreak@gmail.com)
 *
 *	This file is part of TouchMe Games.
 *
 *	TouchMe Games is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	TouchMe Games is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with TouchMe Games; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <dartCountUp.h>
#include <algorithm>
#include <sstream>
#include <iomanip>
#include <termios.h>
#include <unistd.h>

GtkWidget *DART_COUNTUP::createOpenScreen() {
	GtkWidget *label;
	GtkWidget *button;
	GtkRcStyle *whiteStyle, *blackStyle;
	GdkColor color;
	GtkWidget *hbox;
	
	color.red = 0x4600;
	color.green = 0x8200;
	color.blue = 0xB400;
	
	table = gtk_table_new(3, 2, FALSE);
	gtk_table_set_col_spacings((GtkTable *)table, 40);
	gtk_table_set_row_spacings((GtkTable *)table, 40);

	
	whiteStyle = gtk_rc_style_new();//gtk_widget_get_modifier_style(label);
	whiteStyle->font_desc = pango_font_description_new();
	pango_font_description_set_size(whiteStyle->font_desc, 28 * PANGO_SCALE);
	pango_font_description_set_weight(whiteStyle->font_desc, PANGO_WEIGHT_BOLD);
	color.red = 0xFFFF;
	color.green = 0xFFFF;
	color.blue = 0xFFFF;
	whiteStyle->fg[0] = color;
	whiteStyle->color_flags[0] = GTK_RC_FG;
	
	blackStyle = gtk_rc_style_new();//gtk_widget_get_modifier_style(label);
	blackStyle->font_desc = pango_font_description_new();
	pango_font_description_set_size(blackStyle->font_desc, 28 * PANGO_SCALE);
	pango_font_description_set_weight(blackStyle->font_desc, PANGO_WEIGHT_BOLD);
	color.red = 0;
	color.green = 0;
	color.blue = 0;
	blackStyle->fg[0] = color;
	blackStyle->text[0] = color;
	blackStyle->color_flags[0] = (GtkRcFlags)(GTK_RC_FG | GTK_RC_TEXT);
	
	
	label = gtk_label_new("Number Of Players: ");
	gtk_misc_set_alignment((GtkMisc *)label, 0, 0.5);
	gtk_widget_modify_style(label, whiteStyle);
	
	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
			  (GtkAttachOptions)0,
			  (GtkAttachOptions)(0), 0, 0);
	
	hbox = gtk_hbox_new(FALSE, 10);
	numPlayersEntry = gtk_entry_new();
	gtk_entry_set_width_chars((GtkEntry *)numPlayersEntry, 3);
	gtk_entry_set_text((GtkEntry *)numPlayersEntry, "1");
	gtk_entry_set_editable((GtkEntry *)numPlayersEntry, FALSE);
	gtk_entry_set_alignment((GtkEntry *)numPlayersEntry, 1.0);
	gtk_widget_modify_style(numPlayersEntry, blackStyle);
	gtk_box_pack_start((GtkBox *)hbox, numPlayersEntry, FALSE, FALSE, 0);
	
	button = gtk_button_new();
	gtk_widget_set_size_request(button, 150, 75);
	label = gtk_label_new("Change");
	gtk_widget_modify_style(label, blackStyle);
	gtk_misc_set_alignment((GtkMisc *)label, 0.5, 0.5);
	gtk_container_add((GtkContainer *)button, label);
	gtk_box_pack_start((GtkBox *)hbox, button, FALSE, FALSE, 0);
	g_signal_connect(G_OBJECT(button), "clicked",
			 G_CALLBACK(changeNumPlayers), (gpointer)numPlayersEntry);
	
	gtk_table_attach (GTK_TABLE (table), hbox, 1, 2, 0, 1,
			  (GtkAttachOptions)0,
			  (GtkAttachOptions)(0), 0, 0);
	

	label = gtk_label_new("Double Bull:");
	
	gtk_widget_modify_style(label, whiteStyle);
	gtk_misc_set_alignment((GtkMisc *)label, 0, 0.5);
	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
			  (GtkAttachOptions)(GTK_EXPAND | GTK_FILL),
			  (GtkAttachOptions)(0), 0, 0);
	
	
	button = gtk_button_new();
	gtk_widget_set_size_request(button, 120, 75);
	doubleBullLabel = gtk_label_new("Off");
	gtk_widget_modify_style(doubleBullLabel, blackStyle);
	gtk_misc_set_alignment((GtkMisc *)doubleBullLabel, 0.5, 0.5);

	gtk_container_add((GtkContainer *)button, doubleBullLabel);
	gtk_table_attach (GTK_TABLE (table), button, 1, 2, 1, 2,
			  (GtkAttachOptions)0,
		(GtkAttachOptions)(0), 0, 0);
	g_signal_connect(G_OBJECT(button), "clicked",
			 G_CALLBACK(onOffToggle), (gpointer)doubleBullLabel);
	
	
	button = gtk_button_new();
	
	gtk_widget_set_size_request(button, 220, 75);
	label = gtk_label_new("Start Game");
	gtk_widget_modify_style(label, blackStyle);
	gtk_misc_set_alignment((GtkMisc *)label, 0.5, 0.5);
	
	gtk_container_add((GtkContainer *)button, label);
	
	gtk_table_attach (GTK_TABLE (table), button, 0, 2, 2, 3,
			  (GtkAttachOptions)0,
		(GtkAttachOptions)(0), 0, 0);
	g_signal_connect(G_OBJECT(button), "clicked",
			 G_CALLBACK(startGame), (gpointer)this);
 
 pango_font_description_free(whiteStyle->font_desc);
 pango_font_description_free(blackStyle->font_desc);
 
	return table;
}

void DART_COUNTUP::initScreen() {
	GtkWidget *eventBox;
	GtkWidget *label;
	GtkWidget *hbox, *vbox;
	std::stringstream sstr;
	
	GdkColor color;
	
	GtkRcStyle *rcstyle;
	
	lhvbox = gtk_vbox_new(FALSE, 0);
	gtk_box_pack_start((GtkBox *)tophbox, lhvbox, FALSE, FALSE, 0);
	
	midvbox = gtk_vbox_new(FALSE, 0);
	gtk_widget_set_size_request(midvbox, 400, -1);
	gtk_box_pack_start((GtkBox *)tophbox, midvbox, FALSE, FALSE, 0);
	
	rhvbox = gtk_vbox_new(FALSE, 0);
	gtk_box_pack_start((GtkBox *)tophbox, rhvbox, FALSE, FALSE, 0);
	
	label = gtk_label_new(" ");
	gtk_widget_set_size_request(label, 0, 30);
	gtk_box_pack_start((GtkBox *)lhvbox, label, FALSE, FALSE, 0);
	
	label = gtk_label_new(" ");
	gtk_widget_set_size_request(label, 0, 30);
	gtk_box_pack_start((GtkBox *)rhvbox, label, FALSE, FALSE, 0);
	
	for (int i = 0; i < numberOfPlayers; ++i) {
		sstr.str("");
		sstr << "Player " << i + 1 << " - 0.00";
		playerLabels[i] = gtk_label_new(sstr.str().c_str());
		rcstyle = gtk_rc_style_new();//gtk_widget_get_modifier_style(label);
		rcstyle->font_desc = pango_font_description_new();
		pango_font_description_set_size(rcstyle->font_desc, 20 * PANGO_SCALE);
		pango_font_description_set_weight(rcstyle->font_desc, PANGO_WEIGHT_BOLD);
		color.red = 0xFFFF;
		color.green = 0xFFFF;
		color.blue = 0xFFFF;
		rcstyle->fg[0] = color;
		rcstyle->color_flags[0] = GTK_RC_FG;
		gtk_widget_modify_style(playerLabels[i], rcstyle);
		
		// Start of Player box
		eventBox = gtk_event_box_new();
		gtk_widget_set_size_request(eventBox, 200, 100);
		rcstyle = gtk_rc_style_new();
		color.red = 0x4600;
		color.green = 0x8200;
		color.blue = 0xB400;
		
		rcstyle->bg[0] = color;
		rcstyle->color_flags[0] = GTK_RC_BG;
		rcstyle->bg_pixmap_name[0] = "/usr/local/share/touchmegames/dart01/images/smallscorebg.xpm";
		gtk_widget_modify_style(eventBox, rcstyle);
  pango_font_description_free(rcstyle->font_desc);
		
		//gtk_box_pack_start((GtkBox *)vbox, eventBox, FALSE, FALSE, 0);
		sstr.str("");
		sstr << 0;
		playerScoreLabels[i] = gtk_label_new(sstr.str().c_str());
		rcstyle = gtk_rc_style_new();
		//rcstyle = gtk_widget_get_style(playerScoreLabels[i]);
		rcstyle->font_desc = pango_font_description_new();
		pango_font_description_set_size(rcstyle->font_desc, 60 * PANGO_SCALE);
		color.red = 0xFFFF;
		color.green = 0xFFFF;
		color.blue = 0xFFFF;
		rcstyle->fg[0] = color;
		rcstyle->color_flags[0] = GTK_RC_FG;
		pango_font_description_set_weight(rcstyle->font_desc, PANGO_WEIGHT_BOLD);
		gtk_widget_modify_style(playerScoreLabels[i], rcstyle);

		gtk_container_add((GtkContainer *)eventBox, playerScoreLabels[i]);
		// end of player box
		
		if (i % 2) {
			gtk_box_pack_start((GtkBox *)rhvbox, playerLabels[i], FALSE, FALSE, 1);
			gtk_box_pack_start((GtkBox *)rhvbox, eventBox, FALSE, FALSE, 0);
		}
		else {
			gtk_box_pack_start((GtkBox *)lhvbox, playerLabels[i], FALSE, FALSE, 1);
			gtk_box_pack_start((GtkBox *)lhvbox, eventBox, FALSE, FALSE, 0);
		}
  pango_font_description_free(rcstyle->font_desc);
	}
	
	label = gtk_label_new(" ");
	gtk_widget_set_size_request(label, -1, 20);
	gtk_box_pack_start((GtkBox *)midvbox, label, FALSE, FALSE, 0);
	
	playerLabel = gtk_label_new("Player 1 Score");
	rcstyle = gtk_rc_style_new();
	rcstyle->font_desc = pango_font_description_new();
	pango_font_description_set_size(rcstyle->font_desc, 30 * PANGO_SCALE);
	pango_font_description_set_weight(rcstyle->font_desc, PANGO_WEIGHT_BOLD);
	color.red = 0xFFFF;
	color.green = 0xFFFF;
	color.blue = 0xFFFF;
	rcstyle->fg[0] = color;
	rcstyle->color_flags[0] = GTK_RC_FG;
	gtk_widget_modify_style(playerLabel, rcstyle);
	gtk_box_pack_start((GtkBox *)midvbox, playerLabel, FALSE, FALSE, 0);
	
	label = gtk_label_new(" ");
	gtk_widget_set_size_request(label, -1, 5);
	gtk_box_pack_start((GtkBox *)midvbox, label, FALSE, FALSE, 0);
	
	hbox = gtk_hbox_new(FALSE, 0);
	gtk_widget_set_size_request(hbox, 300, 150);
	eventBox = gtk_event_box_new();
	gtk_widget_set_size_request(eventBox, 300, 150);
	rcstyle = gtk_rc_style_new();
	color.red = 0x4600;
	color.green = 0x8200;
	color.blue = 0xB400;
	rcstyle->bg[0] = color;
	rcstyle->color_flags[0] = GTK_RC_BG;
	rcstyle->bg_pixmap_name[0] = "/usr/local/share/touchmegames/dart01/images/largescorebg.xpm";
	gtk_widget_modify_style(eventBox, rcstyle);
 pango_font_description_free(rcstyle->font_desc);
	
	sstr.str("");
	sstr << 0;
	currentTotalLabel = gtk_label_new(sstr.str().c_str());
	rcstyle = gtk_rc_style_new();
	rcstyle->font_desc = pango_font_description_new();
	pango_font_description_set_size(rcstyle->font_desc, 80 * PANGO_SCALE);
	pango_font_description_set_weight(rcstyle->font_desc, PANGO_WEIGHT_BOLD);
	color.red = 0xFFFF;
	color.green = 0xFFFF;
	color.blue = 0xFFFF;
	rcstyle->fg[0] = color;
	rcstyle->xthickness = 0;
	rcstyle->color_flags[0] = GTK_RC_FG;
	gtk_widget_modify_style(currentTotalLabel, rcstyle);
	gtk_container_add((GtkContainer *)eventBox, currentTotalLabel);
	gtk_box_pack_start((GtkBox *)hbox, eventBox, TRUE, FALSE, 0);
	gtk_box_pack_start((GtkBox *)midvbox, hbox, FALSE, FALSE, 0);
 pango_font_description_free(rcstyle->font_desc);
	
	label = gtk_label_new(" ");
	gtk_widget_set_size_request(label, -1, 10);
	gtk_box_pack_start((GtkBox *)midvbox, label, FALSE, FALSE, 0);
	
	
	label = gtk_label_new("Current Score");
	rcstyle = gtk_rc_style_new();
	rcstyle->font_desc = pango_font_description_new();
	pango_font_description_set_size(rcstyle->font_desc, 30 * PANGO_SCALE);
	pango_font_description_set_weight(rcstyle->font_desc, PANGO_WEIGHT_BOLD);
	color.red = 0xFFFF;
	color.green = 0xFFFF;
	color.blue = 0xFFFF;
	rcstyle->fg[0] = color;
	rcstyle->color_flags[0] = GTK_RC_FG;
	gtk_widget_modify_style(label, rcstyle);
	gtk_box_pack_start((GtkBox *)midvbox, label, FALSE, FALSE, 0);
	
 pango_font_description_free(rcstyle->font_desc);
	label = gtk_label_new(" ");
	gtk_widget_set_size_request(label, -1, 5);
	gtk_box_pack_start((GtkBox *)midvbox, label, FALSE, FALSE, 0);
	
	hbox = gtk_hbox_new(FALSE, 0);
	gtk_widget_set_size_request(hbox, 200, 100);
	eventBox = gtk_event_box_new();
	gtk_widget_set_size_request(eventBox, 200, 100);
	rcstyle = gtk_rc_style_new();
	color.red = 0x4600;
	color.green = 0x8200;
	color.blue = 0xB400;	
	rcstyle->bg[0] = color;
	rcstyle->color_flags[0] = GTK_RC_BG;
	rcstyle->bg_pixmap_name[0] = "/usr/local/share/touchmegames/dart01/images/smallscorebg.xpm";
	gtk_widget_modify_style(eventBox, rcstyle);
	
 pango_font_description_free(rcstyle->font_desc);
 
	currentScoreLabel = gtk_label_new("0");
	rcstyle = gtk_rc_style_new();
	rcstyle->font_desc = pango_font_description_new();
	pango_font_description_set_size(rcstyle->font_desc, 60 * PANGO_SCALE);
	pango_font_description_set_weight(rcstyle->font_desc, PANGO_WEIGHT_BOLD);
	color.red = 0xFFFF;
	color.green = 0xFFFF;
	color.blue = 0xFFFF;
	rcstyle->fg[0] = color;
	rcstyle->color_flags[0] = GTK_RC_FG;
	gtk_widget_modify_style(currentScoreLabel, rcstyle);
	gtk_container_add((GtkContainer *)eventBox, currentScoreLabel);
	
	gtk_box_pack_start((GtkBox *)hbox, eventBox, TRUE, FALSE, 0);
	gtk_box_pack_start((GtkBox *)midvbox, hbox, FALSE, FALSE, 0);
	
 pango_font_description_free(rcstyle->font_desc);
	
	label = gtk_label_new(" ");
	gtk_widget_set_size_request(label, -1, 10);
	gtk_box_pack_start((GtkBox *)midvbox, label, FALSE, FALSE, 0);
	
	round = 1;
	sstr.str("");
	sstr << "Round " << std::setw(3) << round;
	roundLabel = gtk_label_new(sstr.str().c_str());
	rcstyle = gtk_rc_style_new();
	rcstyle->font_desc = pango_font_description_new();
	pango_font_description_set_size(rcstyle->font_desc, 30 * PANGO_SCALE);
	pango_font_description_set_weight(rcstyle->font_desc, PANGO_WEIGHT_BOLD);
	color.red = 0xFFFF;
	color.green = 0xFFFF;
	color.blue = 0xFFFF;
	rcstyle->fg[0] = color;
	rcstyle->color_flags[0] = GTK_RC_FG;
	gtk_widget_modify_style(roundLabel, rcstyle);
	gtk_box_pack_start((GtkBox *)midvbox, roundLabel, FALSE, FALSE, 0);

 pango_font_description_free(rcstyle->font_desc);
	vbox = gtk_vbox_new(FALSE, 0);
	gtk_box_pack_start((GtkBox *)midvbox, vbox, FALSE, FALSE, 0);
	
	for (int i = 0; i < 3; ++i) {
		
		dartImages[i] = gtk_image_new_from_file("/usr/local/share/touchmegames/dart01/images/dart.gif");
		gtk_box_pack_start((GtkBox *)vbox, dartImages[i], FALSE, FALSE, 2);
		dartLabels[i] = gtk_label_new("");
		rcstyle = gtk_rc_style_new();
		rcstyle->font_desc = pango_font_description_new();
		pango_font_description_set_size(rcstyle->font_desc, 23 * PANGO_SCALE);
		pango_font_description_set_weight(rcstyle->font_desc, PANGO_WEIGHT_BOLD);
		color.red = 0xFFFF;
		color.green = 0xFFFF;
		color.blue = 0xFFFF;
		rcstyle->fg[0] = color;
		rcstyle->color_flags[0] = GTK_RC_FG;
		gtk_widget_modify_style(dartLabels[i], rcstyle);
		gtk_box_pack_start((GtkBox *)vbox, dartLabels[i], FALSE, FALSE, 2);
  pango_font_description_free(rcstyle->font_desc);
	}
	
	gtk_widget_destroy(table);
	gtk_widget_show_all(tophbox);
	
	for (int i = 0; i < 3; ++i) {
		gtk_widget_hide(dartLabels[i]);
	}
	openSerial();
	
	timer = gtk_timeout_add(100, timeout, this);
	currentPlayer = 0;
	currentDart = 0;
	currentScore = 0;
}

void DART_COUNTUP::createPPDWindow() {
	GtkWidget *vbox;
	GdkColor color;
	GtkRcStyle *rcstyle;
	
	ppdWindow = gtk_event_box_new();
	
	
	gtk_widget_set_size_request(ppdWindow, 300, 150);
	rcstyle = gtk_rc_style_new();

	rcstyle->bg_pixmap_name[0] = "/usr/local/share/touchmegames/dart01/images/ppdbg.xpm";
	gtk_widget_modify_style(ppdWindow, rcstyle);
	
	gtk_widget_modify_bg(ppdWindow, GTK_STATE_NORMAL, &color);
	
	vbox = gtk_vbox_new(FALSE, 0);
	gtk_container_add((GtkContainer *)ppdWindow, vbox);
	
	ppdPlayerLabel = gtk_label_new("");
	rcstyle = gtk_rc_style_new();
	rcstyle->font_desc = pango_font_description_new();
	pango_font_description_set_size(rcstyle->font_desc, 40 * PANGO_SCALE);
	pango_font_description_set_weight(rcstyle->font_desc, PANGO_WEIGHT_BOLD);
	color.red = 0xFFFF;
	color.green = 0xFFFF;
	color.blue = 0xFFFF;
	rcstyle->fg[0] = color;
	rcstyle->color_flags[0] = GTK_RC_FG;
	
	gtk_widget_modify_style(ppdPlayerLabel, rcstyle);
	ppdLabel = gtk_label_new("");
	gtk_widget_modify_style(ppdLabel, rcstyle);
	
	gtk_box_pack_start((GtkBox *)vbox, ppdPlayerLabel, FALSE, FALSE, 5);
	gtk_box_pack_start((GtkBox *)vbox, ppdLabel, FALSE, FALSE, 5);
	
	gtk_fixed_put(GTK_FIXED(fixed), ppdWindow, 250, 300);
 pango_font_description_free(rcstyle->font_desc);
}

void DART_COUNTUP::createGameOver1() {
	GtkWidget *label;
	GtkWidget *vbox;
	GtkWidget *button;
	GtkWidget *eventBox;
	GdkColor color;
	GtkStyle *style;
	int lh(1), rh(2);
	int round;
	
	std::cout << "Winner " << winner << std::endl;
	
	round = atoi(gtk_label_get_text((GtkLabel *)roundLabel));
	for (int i = 0; i < numberOfPlayers; ++i) {
		finalScore[i] = atoi(gtk_label_get_text((GtkLabel *)playerScoreLabels[i]));
	}
	
	gtk_widget_destroy(lhvbox);
	gtk_widget_destroy(rhvbox);
	gtk_widget_destroy(midvbox);
	
	vbox = gtk_vbox_new(FALSE, 0);
	table = gtk_table_new(8, 9, TRUE);
	gtk_box_pack_start((GtkBox *)vbox, table, FALSE, FALSE, 0);
	gtk_table_set_row_spacings((GtkTable *)table, 3);
	gtk_table_set_col_spacings((GtkTable *)table, 3);
	
	color.red = 0xFFFF;
	color.green = 0xFFFF;
	color.blue = 0xFFFF;
	
	label = gtk_label_new("Winner");
	gtk_misc_set_alignment((GtkMisc *)label, 0, 0.5);
	style = gtk_widget_get_style(label);
	style->fg[0] = color;
	pango_font_description_set_size(style->font_desc, 14 * PANGO_SCALE);
	pango_font_description_set_weight(style->font_desc, PANGO_WEIGHT_BOLD);
	gtk_widget_set_style(label, style);
	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
			  (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
			  (GtkAttachOptions)(0), 0, 0);
	
	label = gtk_label_new("Score");
	gtk_misc_set_alignment((GtkMisc *)label, 0, 0.5);
	gtk_widget_set_style(label, style);
	gtk_table_attach(GTK_TABLE (table), label, 0, 1, 2, 3,
			 (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
			  (GtkAttachOptions)(0), 0, 0);
	
	label = gtk_label_new("Darts");
	gtk_misc_set_alignment((GtkMisc *)label, 0, 0.5);
	style = gtk_widget_get_style(label);
	style->fg[0] = color;
	pango_font_description_set_size(style->font_desc, 14 * PANGO_SCALE);
	pango_font_description_set_weight(style->font_desc, PANGO_WEIGHT_BOLD);
	gtk_widget_set_style(label, style);
	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 3, 4,
			  (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
			  (GtkAttachOptions)(0), 0, 0);
	
	label = gtk_label_new("Doubles");
	gtk_misc_set_alignment((GtkMisc *)label, 0, 0.5);
	gtk_widget_set_style(label, style);
	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 4, 5,
			  (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
			  (GtkAttachOptions)(0), 0, 0);
	
	label = gtk_label_new("Triples");
	gtk_misc_set_alignment((GtkMisc *)label, 0, 0.5);
	gtk_widget_set_style(label, style);
	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 5, 6,
			  (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
			  (GtkAttachOptions)(0), 0, 0);
	
	label = gtk_label_new("Bulls");
	gtk_misc_set_alignment((GtkMisc *)label, 0, 0.5);
	gtk_widget_set_style(label, style);
	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 6, 7,
			  (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
			  (GtkAttachOptions)(0), 0, 0);
			  
			  
	label = gtk_label_new("PPD");
	gtk_misc_set_alignment((GtkMisc *)label, 0, 0.5);
	gtk_widget_set_style(label, style);
	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 7, 8,
			  (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
			  (GtkAttachOptions)(0), 0, 0);
	
	label = gtk_label_new("PPR");
	gtk_misc_set_alignment((GtkMisc *)label, 0, 0.5);
	gtk_widget_set_style(label, style);
	gtk_table_attach(GTK_TABLE (table), label, 0, 1, 8, 9,
			 (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
			  (GtkAttachOptions)(0), 0, 0);
	
	
	for (int i = 0; i < numberOfPlayers; ++i) {
		std::stringstream sstr;
		// Label
		sstr << "Player " << i + 1;
		label = gtk_label_new(sstr.str().c_str());
		gtk_misc_set_alignment((GtkMisc *)label, 1, 0.5);
		gtk_widget_set_style(label, style);
		gtk_table_attach(GTK_TABLE (table), label, lh, rh, 0, 1,
				 (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
				 (GtkAttachOptions)(0), 0, 0);
		
		sstr.str("");
		sstr << (winner == i ? 1: 0);
		label = gtk_label_new(sstr.str().c_str());
		gtk_misc_set_alignment((GtkMisc *)label, 1, 0.5);
		gtk_widget_set_style(label, style);
		gtk_table_attach(GTK_TABLE (table), label, lh, rh, 1, 2,
				 (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
				 (GtkAttachOptions)(0), 0, 0);
				 
		sstr.str("");
		sstr << (float)finalScore[i];
		label = gtk_label_new(sstr.str().c_str());
		gtk_misc_set_alignment((GtkMisc *)label, 1, 0.5);
		gtk_widget_set_style(label, style);
		gtk_table_attach(GTK_TABLE (table), label, lh, rh, 2, 3,
				 (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
				 (GtkAttachOptions)(0), 0, 0);
		
		sstr.str("");
		sstr << darts[i];
		label = gtk_label_new(sstr.str().c_str());
		gtk_misc_set_alignment((GtkMisc *)label, 1, 0.5);
		gtk_widget_set_style(label, style);
		gtk_table_attach(GTK_TABLE (table), label, lh, rh, 3, 4,
				 (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
				 (GtkAttachOptions)(0), 0, 0);
		
		sstr.str("");
		sstr << doubles[i];
		label = gtk_label_new(sstr.str().c_str());
		gtk_misc_set_alignment((GtkMisc *)label, 1, 0.5);
		gtk_widget_set_style(label, style);
		gtk_table_attach(GTK_TABLE (table), label, lh, rh, 4, 5,
				 (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
				 (GtkAttachOptions)(0), 0, 0);
		
		sstr.str("");
		sstr << triples[i];
		label = gtk_label_new(sstr.str().c_str());
		gtk_misc_set_alignment((GtkMisc *)label, 1, 0.5);
		gtk_widget_set_style(label, style);
		gtk_table_attach(GTK_TABLE (table), label, lh, rh, 5, 6,
				 (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
				 (GtkAttachOptions)(0), 0, 0);
		
		sstr.str("");
		sstr << bulls[i];
		label = gtk_label_new(sstr.str().c_str());
		gtk_misc_set_alignment((GtkMisc *)label, 1, 0.5);
		gtk_widget_set_style(label, style);
		gtk_table_attach(GTK_TABLE (table), label, lh, rh, 6, 7,
				 (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
				 (GtkAttachOptions)(0), 0, 0);
				 
		sstr.str("");
		sstr << std::setprecision(3) << (float)finalScore[i] / (float)darts[i];
		label = gtk_label_new(sstr.str().c_str());
		gtk_misc_set_alignment((GtkMisc *)label, 1, 0.5);
		gtk_widget_set_style(label, style);
		gtk_table_attach(GTK_TABLE (table), label, lh, rh, 7, 8,
				 (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
				 (GtkAttachOptions)(0), 0, 0);
		
		sstr.str("");
		sstr << std::setprecision(4) << (float)finalScore[i] / (float)rounds[i];
		label = gtk_label_new(sstr.str().c_str());
		gtk_misc_set_alignment((GtkMisc *)label, 1, 0.5);
		gtk_widget_set_style(label, style);
		gtk_table_attach(GTK_TABLE (table), label, lh, rh, 8, 9,
				 (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
				 (GtkAttachOptions)(0), 0, 0);
		
		++rh;
		++lh;
	}
	eventBox = gtk_event_box_new();
	button = gtk_image_new_from_file("/usr/local/share/touchmegames/dart01/images/exitgame.gif");
	gtk_event_box_set_visible_window((GtkEventBox *)eventBox, FALSE);
	gtk_widget_add_events(eventBox, GDK_BUTTON_PRESS_MASK);
	g_signal_connect(G_OBJECT(eventBox), 
			 "button-press-event",
			 G_CALLBACK(exitGame), (gpointer)this);
	
	gtk_container_add((GtkContainer *)eventBox, button);
	gtk_box_pack_start((GtkBox *)vbox, eventBox, FALSE, FALSE, 50);
	gtk_box_pack_start((GtkBox *)tophbox, vbox, FALSE, FALSE, 0);
	gtk_widget_show_all(vbox);
}

GtkWidget *DART_COUNTUP::init() {
	GAME_PTR::loadScores(scores);
	
	for (int i = 0; i < 8; ++i) {
		darts[i] = 0;
		finalScore[i] = 0;
		rounds[i] = 0;
		doubles[i] = 0;
		triples[i] = 0;
		bulls[i] = 0;
	}
	winner = -1;
	beginningScore = 0; // for when the player busts
	
	fixed = gtk_fixed_new();
	gtk_widget_ref(fixed);
	
	tophbox = gtk_hbox_new(FALSE, 0);
	
	createPPDWindow();
	
	gtk_box_pack_start((GtkBox *)tophbox, createOpenScreen(), TRUE, FALSE, 5);
	
	gtk_fixed_put(GTK_FIXED(fixed), tophbox, 0, 0);
	gtk_widget_show_all(fixed);
	gtk_widget_hide_all(ppdWindow);
	return fixed;
}

void DART_COUNTUP::openSerial() {
	if (!dartBoard.init("/dev/ttyS0")) {
		std::cout << "No init" << std::endl;
	}
	if (!dartBoard.dartBoardPresent()) {
		// we gots ourselves some trouble.
	}
}
