
/*	Copyright (C) 2005, 2006 by Andy Grebe a.k.a. tecknophreak(tecknophreak@gmail.com)
 *
 *	This file is part of TouchMe Games.
 *
 *	TouchMe Games is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	TouchMe Games is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with TouchMe Games; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 

// events for DartCountDown

#include <dartcountdown.h>
#include <algorithm>
#include <sstream>
#include <iostream>
#include <iomanip>


void DartCountDown::exitGame(GtkWidget *widget, GdkEvent *event, gpointer ptr) {
	DartCountDown *g(reinterpret_cast<DartCountDown *>(ptr));
	SCORE_STRUCT newScore;
	
	std::cout << "High score: " << g->highScore << std::endl;
	
	newScore.name = "";
	newScore.fscore = g->highScore;
	newScore.date = "";
	
	g->GAME_PTR::addScore(g->scores, newScore);
	
	
	g->GAME_PTR::saveScores(g->scores);
	
	gtk_widget_hide(g->fixed);
	
	g_source_remove(g->timer);
	
	g->dartBoard.closeDart();
}

gboolean DartCountDown::timeout(gpointer ptr) {
	DartCountDown *dart(reinterpret_cast<DartCountDown *>(ptr));
	int score, totScore;
	std::stringstream sstr;
	timeval tv;
	int seconds;
	
	gettimeofday(&tv, &dart->tz);
	seconds = tv.tv_sec - dart->startTime.tv_sec;
	sstr << std::setw(2) << std::setfill('0') << seconds / 60 
			<< ':' << std::setw(2) << std::setfill('0') << seconds % 60;
	
	gtk_label_set_text((GtkLabel *)dart->playerScoreLabels[1], sstr.str().c_str());
	sstr.str("");
	if (dart->gameState == DROPPING_LOW_TON) {
		if (dart->lowTonY == 300) {
			if (++dart->currentDart > 43) {
				dart->currentDart = 22;
				dart->gameState = PLAYING;
				gtk_fixed_move((GtkFixed *)dart->fixed, dart->lowTon, 250, -300);
				dart->didTon = true;
			}
			return TRUE;
		}
		dart->lowTonY += 50;
		std::cout << "Dart lowtony " << dart->lowTonY << std::endl;
		gtk_fixed_move((GtkFixed *)dart->fixed, dart->lowTon, 250, dart->lowTonY);
		return TRUE;
	}
	else if (dart->gameState == DROPPING_HIGH_TON) {
		if (dart->highTonY == 200) {
			if (++dart->currentDart > 43) {
				dart->currentDart = 22;
				dart->gameState = PLAYING;
				gtk_fixed_move((GtkFixed *)dart->fixed, dart->highTon, 200, -400);
				dart->didTon = true;
			}
			return TRUE;
		}
		dart->highTonY += 50;
		gtk_fixed_move((GtkFixed *)dart->fixed, dart->highTon, 200, dart->highTonY);
		return TRUE;
	}
	else if (dart->gameState == DROPPING_TON_80) {
		if (dart->ton80Y == 0) {
			if (++dart->currentDart > 43) {
				dart->currentDart = 22;
				dart->gameState = PLAYING;
				gtk_fixed_move((GtkFixed *)dart->fixed, dart->ton80, 100, -600);
				dart->didTon = true;
			}
			return TRUE;
		}
		dart->ton80Y += 50;
		gtk_fixed_move((GtkFixed *)dart->fixed, dart->ton80, 100, dart->ton80Y);
		return TRUE;
	}
	
	if (dart->currentDart <= 2) {
		int a, x(0);
		if (!dart->dartBoard.gotDart()) {
			return TRUE;
		}
		dart->dartBoard.readDart(x, a);
		
		if (a == 2) {
			++dart->doubles[dart->currentPlayer];
		}
		else if (a == 3) {
			++dart->triples[dart->currentPlayer];
		}
		
		if (x == 25 || x == 50) {
			++dart->bulls[dart->currentPlayer];
			std::cout << "I'm an idiot!!" << std::endl;
		}
		
		score = x * a;
		
		// Incoming dart
		totScore = atoi(gtk_label_get_text((GtkLabel *)dart->playerScoreLabels[dart->currentPlayer]));
		totScore -= score;
		++dart->darts[dart->currentPlayer];
		if (totScore < 0) {
			gtk_label_set_text((GtkLabel *)dart->currentTotalLabel, "BUST");
			
			sstr.str("");
			sstr << dart->beginningScore;
			gtk_label_set_text((GtkLabel *)dart->playerScoreLabels[dart->currentPlayer], sstr.str().c_str());
			
			sstr.str("");
			if (a == 1) {
				sstr << "Single ";
				if (x < 25) {
					sstr << score;
				}
				else if (score / a == 25) {
					sstr << "BULL";
				}
			}
			else if (a == 2) {
				sstr << "Double ";
				if (x < 25) {
					sstr << score / a;
				}
				else if (score / a == 25) {
					sstr << "BULL";
				}
			}
			else if (a == 3) {
				sstr << "Triple " << score / a;
				
			}
			gtk_label_set_text((GtkLabel *)dart->dartLabels[dart->currentDart], sstr.str().c_str());
			gtk_widget_show(dart->dartLabels[dart->currentDart]);
			gtk_widget_hide(dart->dartImages[dart->currentDart]);
			
			dart->currentDart = 3;
		}
		else {
			sstr << totScore;
			gtk_label_set_text((GtkLabel *)dart->playerScoreLabels[dart->currentPlayer], sstr.str().c_str());
			gtk_label_set_text((GtkLabel *)dart->currentTotalLabel, sstr.str().c_str());
			dart->currentScore += score;
			
			sstr.str("");
			if (a == 1) {
				sstr << "Single ";
				if (x < 25) {
					sstr << score;
				}
				else {
					sstr << "BULL";
				}
			}
			else if (a == 2) {
				sstr << "Double ";
				if (x < 25) {
					sstr << score / a;
				}
				else {
					sstr << "BULL";
				}
			}
			else if (a == 3) {
				sstr << "Triple " << score / a;
				
			}
			gtk_label_set_text((GtkLabel *)dart->dartLabels[dart->currentDart], sstr.str().c_str());
			gtk_widget_show(dart->dartLabels[dart->currentDart]);
			
			sstr.str("");
			sstr << dart->currentScore;
			gtk_label_set_text((GtkLabel *)dart->currentScoreLabel, sstr.str().c_str());
			gtk_widget_hide(dart->dartImages[dart->currentDart++]);
			
		}
		if (totScore == 0) {
			std::cout << "Game Over!!" << std::endl;
			
			++dart->rounds[dart->currentPlayer];
			dart->winner = dart->currentPlayer;
			
			if (!dart->lastChanceDarts) {
				dart->gameState = GAME_OVER1;
				dart->createGameOver1();
				return FALSE;
			}
			else {
				dart->currentDart = 3;
			}
		}
	}
	else {
		if (dart->currentDart == 3) {
			int player;
			float ppd(0.0), points;
			dart->dartBoard.pause();
			// PPD Above each player's score
			++dart->rounds[dart->currentPlayer];
			player = dart->currentPlayer;
			points = (301 - atoi(gtk_label_get_text(
					(GtkLabel *)dart->playerScoreLabels[player])));
			
			if (dart->darts[player]) {
				ppd = points / (float)(dart->darts[player]);
			}
			else {
				ppd = 0.0;
			}
			
			sstr.str("");
			sstr << "Player " << player + 1 << " - " << std::setprecision(3) << ppd;
			gtk_label_set_text((GtkLabel *)dart->playerLabels[player], sstr.str().c_str());
		}
		else if (dart->currentDart == 23) {
			int player, p;
			float ppd(0.0), points;
			
			
			p = atoi(gtk_label_get_text((GtkLabel *)dart->currentScoreLabel));
			// no low ton for this game
/*			if ((p == 180) && !dart->didTon) {
				++dart->ton80s[dart->currentPlayer];
				dart->maxTon[dart->currentPlayer] = 180;
				dart->createTon80();
				dart->gameState = DROPPING_TON_80;
				return TRUE;
			}
			else if ((p > 149) && !dart->didTon) {
				++dart->highTons[dart->currentPlayer];
				if (p > dart->maxTon[dart->currentPlayer]) {
					dart->maxTon[dart->currentPlayer] = p;
				}
				dart->createHighTon();
				dart->gameState = DROPPING_HIGH_TON;
				return TRUE;
			}
			else if (p > 99 && !dart->didTon) {
				++dart->lowTons[dart->currentPlayer];
				if (p > dart->maxTon[dart->currentPlayer]) {
					dart->maxTon[dart->currentPlayer] = p;
				}
				dart->createLowTon();
				dart->gameState = DROPPING_LOW_TON;
				return TRUE;
			}
*/
			dart->didTon = false;
			
			// get the next player's PPD going
			if (dart->currentPlayer + 1 == dart->numberOfPlayers) {
				player = 0;
				std::cout << "Winner: " << dart->winner << ' ' <<  __LINE__ << std::endl;
				if (dart->winner >= 0) {
					dart->gameState = GAME_OVER1;
					dart->createGameOver1();
					return FALSE;
				}
			}
			else {
				player = dart->currentPlayer + 1;
			}
			
			points = (301 - atoi(gtk_label_get_text(
					(GtkLabel *)dart->playerScoreLabels[player])));
			
			if (dart->darts[player]) {
				ppd = points / (float)(dart->darts[player]);
			}
			else {
				ppd = 0.0;
			}
			sstr.str("");
			sstr << "Player " << player + 1;
			gtk_label_set_text((GtkLabel *)dart->ppdPlayerLabel, sstr.str().c_str());
			
			sstr.str("");
			sstr << "PPD: " << std::setprecision(3) << ppd;
			
			gtk_label_set_text((GtkLabel *)dart->ppdLabel, sstr.str().c_str());
			
			gtk_widget_show_all(dart->ppdWindow);
			
		}
		++dart->currentDart;
	}
	if (dart->currentDart == 43) {
		dart->currentDart = 0;
		gtk_widget_show(dart->dartImages[0]);
		gtk_widget_show(dart->dartImages[1]);
		gtk_widget_show(dart->dartImages[2]);
		gtk_widget_hide(dart->dartLabels[0]);
		gtk_widget_hide(dart->dartLabels[1]);
		gtk_widget_hide(dart->dartLabels[2]);
		dart->currentScore = 0;
		gtk_label_set_text((GtkLabel *)dart->currentScoreLabel, "0");
		
		if (++dart->currentPlayer == dart->numberOfPlayers) {
			dart->currentPlayer = 0;
			++dart->round;
			sstr.str("");
			sstr << "Round " << std::setw(3) << dart->round;
			gtk_label_set_text((GtkLabel *)dart->roundLabel, sstr.str().c_str());
			
		}
		dart->beginningScore = atoi(gtk_label_get_text((GtkLabel *)dart->playerScoreLabels[dart->currentPlayer]));
		gtk_label_set_text((GtkLabel *)dart->currentTotalLabel,
				    gtk_label_get_text((GtkLabel *)dart->playerScoreLabels[dart->currentPlayer]));
		
		sstr.str("");
		sstr << "Player " << dart->currentPlayer + 1 << " Score";
		gtk_label_set_text((GtkLabel *)dart->playerLabel, sstr.str().c_str());
		gtk_widget_hide_all(dart->ppdWindow);
		dart->dartBoard.unpause();
	}
	return TRUE;
}

void DartCountDown::onOffToggle(GtkWidget *widget, gpointer ptr) {
	std::string str;
	str = gtk_label_get_text((GtkLabel *)ptr);
	if (str[1] == 'n') {
		gtk_label_set_text((GtkLabel *)ptr, "Off");
	}
	else {
		gtk_label_set_text((GtkLabel *)ptr, "On");
	}
}

void DartCountDown::startGame(GtkWidget *widget, gpointer ptr) {
	DartCountDown *dart((DartCountDown *)ptr);
	std::cout << "Start game" << std::endl;
	std::cout.flush();
	dart->doubleBullOn = strcmp(gtk_label_get_text((GtkLabel *)dart->doubleBullLabel), "On") == 0 ? true: false;
	std::cout << "Start game" << std::endl;
	std::cout.flush();
	((DartCountDown *)ptr)->initScreen();
	std::cout << "Start game" << std::endl;
	std::cout.flush();
	dart->dartBoard.setDoubleBull(dart->doubleBullOn);
	std::cout << "Start game" << std::endl;
	std::cout.flush();
}

