
/*	Copyright (C) 2005, 2006 by Andy Grebe a.k.a. tecknophreak(tecknophreak@gmail.com)
 *
 *	This file is part of TouchMe Games.
 *
 *	TouchMe Games is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	TouchMe Games is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with TouchMe Games; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// events

#include <touchmegames.h>

void TOUCHME_GAMES::showHighScores(GtkWidget *widget, GdkEvent *event, gpointer ptr) {
    TOUCHME_GAMES *sg(reinterpret_cast<TOUCHME_GAMES *>(ptr));
    GtkWidget *w;
    GdkColor *color;
    GtkStyle *style;
    int game;
    
    if (sg->lastGameSelected) {
            gtk_event_box_set_visible_window((GtkEventBox *)sg->lastGameSelected, FALSE);
            gtk_widget_destroy(sg->previewTable);
    }
    
    game = (int)gtk_object_get_user_data((GtkObject *)widget);

    gtk_fixed_move((GtkFixed *)sg->gameSelectFixed, sg->gameBg, (game & 1 ? 160: 10), ((game / 2) * 140) + 60);
    gtk_widget_show(sg->gameBg);

    sg->lastGameSelected = widget;
    
    sg->createPreviewBox(sg->gameMap[widget]);
    gtk_widget_show(sg->startButton);
    gtk_widget_show(sg->aboutButton);
}

void TOUCHME_GAMES::showHelp(GtkWidget *widget, GdkEvent *event, gpointer ptr) {
    TOUCHME_GAMES *sg(reinterpret_cast<TOUCHME_GAMES *>(ptr));
    GtkWidget *w;
    GdkColor *color;
    GtkStyle *style;
    if (sg->lastGameSelected) {
            gtk_widget_destroy(sg->previewTable);
    }
    
    sg->createHelpBox(sg->gameMap[sg->lastGameSelected]);
}

void TOUCHME_GAMES::startGame(GtkWidget *widget, GdkEvent *event, gpointer ptr) {
    TOUCHME_GAMES *sg(reinterpret_cast<TOUCHME_GAMES *>(ptr));
    GtkWidget *w;
    GdkColor *color;
    GtkStyle *style;
    
    if (sg->lastGameSelected) {
        widget = sg->lastGameSelected;
    }
    
    
    color = sg->gameMap[widget]->backgroundColor();
    if (color != NULL) {
        GdkColor c;
        c.red = 0;
        c.green = 0;
        c.blue = 0;
        style = sg->mainStyle;
        style->bg[0] = *color;


        gtk_widget_modify_bg(sg->topWindow, GTK_STATE_NORMAL, color);
    }
    gtk_widget_hide(sg->gameSelectFixed);

    //gtk_widget_hide(sg->gameBg);
    w = sg->gameMap[widget]->init();
    gtk_box_pack_start((GtkBox *)sg->topVbox, w, FALSE, FALSE, 0);
    g_signal_connect(G_OBJECT(w), "hide",
                        G_CALLBACK(gameEnded), sg);
}

void TOUCHME_GAMES::gameEnded(GtkWidget *widget, gpointer ptr) {
    TOUCHME_GAMES *sg(reinterpret_cast<TOUCHME_GAMES *>(ptr));
    GdkColor color;
//    std::cout << "Game Ended started" << std::endl;
//    std::cout.flush();
    gtk_widget_destroy(widget);
    
//    std::cout << "Game Ended " << __LINE__ << std::endl;
//    std::cout.flush();
    
    gtk_widget_show_all(sg->gameSelectFixed);
    
//    std::cout << "Game Ended " << __LINE__ << std::endl;
//    std::cout.flush();
    
    color.red = 0x9000;
    color.green = 0x9000;
    color.blue = 0x9000;
    
    gtk_widget_modify_bg(sg->topWindow, (GtkStateType)0, &color);
    
//    std::cout << "Game Ended " << __LINE__ << std::endl;
//    std::cout.flush();
    if (sg->lastGameSelected) {
	    gtk_event_box_set_visible_window((GtkEventBox *)sg->lastGameSelected, FALSE);
//	    std::cout << "Deleting: " << sg->previewTable << std::endl;
//	    std::cout.flush();
	    gtk_widget_destroy(sg->previewTable);
    }
    
//    std::cout << "Game Ended " << __LINE__ << std::endl;
//    std::cout.flush();
    sg->createPreviewBox(sg->gameMap[sg->lastGameSelected]);
    //gtk_widget_hide(sg->gameBg);
//    std::cout << "Game Ended Finished" << std::endl;
//    std::cout.flush();
}

void TOUCHME_GAMES::showSubMenu(GtkWidget *widget, GdkEvent *event, gpointer ptr) {
    TOUCHME_GAMES *sg(reinterpret_cast<TOUCHME_GAMES *>(ptr));
    int gameType((int)gtk_object_get_user_data((GtkObject *)widget));
    
//     std::cout << "Show Sub Menu Started" << std::endl;
//     std::cout.flush();
    if (sg->lastGameSelected) {
        sg->lastGameSelected = false;
        gtk_widget_destroy(sg->previewTable);
    }
    sg->addGamesToWindow(gameType, 0);
    gtk_widget_hide(sg->mainMenu);
    gtk_widget_show_all(sg->gameSelectFixed);
    gtk_widget_hide(sg->gameBg);
    gtk_widget_hide(sg->startButton);
    gtk_widget_hide(sg->aboutButton);
    
//     std::cout << "Show Sub Menu Ended" << std::endl;
//     std::cout.flush();
}

void TOUCHME_GAMES::showMain(GtkWidget *widget, GdkEvent *event, gpointer ptr) {
	TOUCHME_GAMES *sg(reinterpret_cast<TOUCHME_GAMES *>(ptr));
	
	gtk_widget_show(sg->bgImage);
 gtk_image_set_from_file((GtkImage *)sg->bgImage, "/usr/local/share/touchmegames/images/mainmenu/bg_main.png");
	
	if (sg->gameTable != NULL) {
		gtk_widget_destroy(sg->gameTable);
		sg->gameTable = NULL;
	}
	
 gtk_widget_hide(sg->gameSelectFixed);
	gtk_widget_show_all(sg->mainMenu);
	
	gtk_widget_hide(sg->aboutBox);
	gtk_widget_show(sg->mainAbout);
	gtk_widget_hide(sg->mainBack);
 gtk_widget_hide(sg->gameBg);
}

void TOUCHME_GAMES::showAbout(GtkWidget *widget, GdkEvent *event, gpointer ptr) {
    TOUCHME_GAMES *sg(reinterpret_cast<TOUCHME_GAMES *>(ptr));
    
    for (int i = 0; i < 5; ++i) {
        gtk_widget_hide(sg->menuWidgets[i]);
        gtk_widget_hide(sg->menuCaptions[i]);
    }
    
    gtk_widget_show(sg->aboutBox);
    gtk_widget_hide(sg->mainAbout);
    gtk_widget_show(sg->mainBack);
}

void TOUCHME_GAMES::leftArrowPressed(GtkWidget *widget, GdkEvent *event, gpointer ptr) {
    TOUCHME_GAMES *tg(reinterpret_cast<TOUCHME_GAMES *>(ptr));
    unsigned long val;
    
    val = (int)gtk_object_get_user_data((GtkObject *)widget);
    if (tg->gameTable != NULL) {
            gtk_widget_destroy(tg->gameTable);
    }
    tg->addGamesToWindow(val >> 16, val & 0xFFFF);
    gtk_widget_hide(tg->mainMenu);
    gtk_widget_show_all(tg->gameSelectFixed);
    gtk_widget_hide(tg->gameBg);

}

void TOUCHME_GAMES::rightArrowPressed(GtkWidget *widget, GdkEvent *event, gpointer ptr) {
    TOUCHME_GAMES *tg(reinterpret_cast<TOUCHME_GAMES *>(ptr));
    unsigned long val;
    
    val = (int)gtk_object_get_user_data((GtkObject *)widget);
    if (tg->gameTable != NULL) {
            gtk_widget_destroy(tg->gameTable);
    }
    tg->addGamesToWindow(val >> 16, val & 0xFFFF);
    gtk_widget_hide(tg->mainMenu);
    gtk_widget_show_all(tg->gameSelectFixed);
    gtk_widget_hide(tg->gameBg);
}
